==> kubernetes-model-apiextensions-5.9.0-sources.jar: io/fabric8/kubernetes/api/model/apiextensions/v1/WebhookConversionBuilder.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class WebhookConversionBuilder extends io.fabric8.kubernetes.api.model.apiextensions.v1.WebhookConversionFluentImpl<io.fabric8.kubernetes.api.model.apiextensions.v1.WebhookConversionBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.apiextensions.v1.WebhookConversion,io.fabric8.kubernetes.api.model.apiextensions.v1.WebhookConversionBuilder>{
  public WebhookConversionBuilder() {
    this(false);
  }
  public WebhookConversionBuilder(java.lang.Boolean validationEnabled) {
    this(new WebhookConversion(), validationEnabled);
  }
  public WebhookConversionBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1.WebhookConversionFluent<?> fluent) {
    this(fluent, false);
  }
  public WebhookConversionBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1.WebhookConversionFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new WebhookConversion(), validationEnabled);
  }
  public WebhookConversionBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1.WebhookConversionFluent<?> fluent,io.fabric8.kubernetes.api.model.apiextensions.v1.WebhookConversion instance) {
    this(fluent, instance, false);
  }
  public WebhookConversionBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1.WebhookConversionFluent<?> fluent,io.fabric8.kubernetes.api.model.apiextensions.v1.WebhookConversion instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withClientConfig(instance.getClientConfig()); 
    fluent.withConversionReviewVersions(instance.getConversionReviewVersions()); 
    this.validationEnabled = validationEnabled; 
  }
  public WebhookConversionBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1.WebhookConversion instance) {
    this(instance,false);
  }
  public WebhookConversionBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1.WebhookConversion instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withClientConfig(instance.getClientConfig()); 
    this.withConversionReviewVersions(instance.getConversionReviewVersions()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.apiextensions.v1.WebhookConversionFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.apiextensions.v1.WebhookConversion build() {
    WebhookConversion buildable = new WebhookConversion(fluent.getClientConfig(),fluent.getConversionReviewVersions());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    WebhookConversionBuilder that = (WebhookConversionBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> kubernetes-model-apiextensions-5.12.2-sources.jar: io/fabric8/kubernetes/api/model/apiextensions/v1/WebhookConversionBuilder.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class WebhookConversionBuilder extends io.fabric8.kubernetes.api.model.apiextensions.v1.WebhookConversionFluentImpl<io.fabric8.kubernetes.api.model.apiextensions.v1.WebhookConversionBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.apiextensions.v1.WebhookConversion,io.fabric8.kubernetes.api.model.apiextensions.v1.WebhookConversionBuilder>{
  public WebhookConversionBuilder() {
    this(false);
  }
  public WebhookConversionBuilder(java.lang.Boolean validationEnabled) {
    this(new WebhookConversion(), validationEnabled);
  }
  public WebhookConversionBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1.WebhookConversionFluent<?> fluent) {
    this(fluent, false);
  }
  public WebhookConversionBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1.WebhookConversionFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new WebhookConversion(), validationEnabled);
  }
  public WebhookConversionBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1.WebhookConversionFluent<?> fluent,io.fabric8.kubernetes.api.model.apiextensions.v1.WebhookConversion instance) {
    this(fluent, instance, false);
  }
  public WebhookConversionBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1.WebhookConversionFluent<?> fluent,io.fabric8.kubernetes.api.model.apiextensions.v1.WebhookConversion instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withClientConfig(instance.getClientConfig()); 
    fluent.withConversionReviewVersions(instance.getConversionReviewVersions()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public WebhookConversionBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1.WebhookConversion instance) {
    this(instance,false);
  }
  public WebhookConversionBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1.WebhookConversion instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withClientConfig(instance.getClientConfig()); 
    this.withConversionReviewVersions(instance.getConversionReviewVersions()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.apiextensions.v1.WebhookConversionFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.apiextensions.v1.WebhookConversion build() {
    WebhookConversion buildable = new WebhookConversion(fluent.getClientConfig(),fluent.getConversionReviewVersions());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    WebhookConversionBuilder that = (WebhookConversionBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
